# Modeling: Middleware and APIs (Meta Model v3)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/middleware-and-apis-modeling-v3?version=CLOUD#overview)
  * [How to model middleware in LeanIX](https://help.sap.com/docs/leanix/ea/middleware-and-apis-modeling-v3?version=CLOUD#how-to-model-middleware-in-leanix)
  * [1. Modeling middleware as an Application:](https://help.sap.com/docs/leanix/ea/middleware-and-apis-modeling-v3?version=CLOUD#1.-modeling-middleware-as-an-application:)
  * [2. Modeling middleware as an IT Component](https://help.sap.com/docs/leanix/ea/middleware-and-apis-modeling-v3?version=CLOUD#2.-modeling-middleware-as-an-it-component)
  * [APIs](https://help.sap.com/docs/leanix/ea/middleware-and-apis-modeling-v3?version=CLOUD#apis)
  * [How to model APIs in LeanIX](https://help.sap.com/docs/leanix/ea/middleware-and-apis-modeling-v3?version=CLOUD#how-to-model-apis-in-leanix)


In this section, you will find best practices for modeling middleware and APIs.
